aboutsummaryrefslogtreecommitdiff
path: root/filehtml.go
diff options
context:
space:
mode:
authorShulhan <ms@kilabit.info>2019-08-05 22:43:20 +0700
committerShulhan <ms@kilabit.info>2019-08-05 22:43:20 +0700
commit616712b8a644fc346681d112ce3f866315371c83 (patch)
tree42e514d8df8cb8b1821b78f968820890e0773acb /filehtml.go
parentf9fe8ce6ed15a05a7ee15a12ed34973f33372b72 (diff)
downloadciigo-616712b8a644fc346681d112ce3f866315371c83.tar.xz
all: add support for markdown markup language
Due to the popularity of markdown format, we decide to support converting markdown file in ciigo. While at it ignore all files or directories that start with dot, which are hidden file in unix-like system.
Diffstat (limited to 'filehtml.go')
-rw-r--r--filehtml.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/filehtml.go b/filehtml.go
index 9e023ec..d88f2da 100644
--- a/filehtml.go
+++ b/filehtml.go
@@ -35,10 +35,10 @@ func (fhtml *fileHTML) reset() {
}
//
// unpackAdoc convert the asciidoc metadata to its HTML representation and
// rawBody to template.HTML.
//
-func (fhtml *fileHTML) unpackAdoc(fa *fileAdoc) {
+func (fhtml *fileHTML) unpackMarkup(fa *markupFile) {
fhtml.Metadata = make(map[string]string)
for k, v := range fa.metadata {
@@ -35,10 +35,10 @@ func (fhtml *fileHTML) reset() {
}
//
-// unpackAdoc convert the asciidoc metadata to its HTML representation and
+// unpackMarkup convert the markup metadata to its HTML representation and
// rawBody to template.HTML.
//